==> haskell-loop-0.3.0-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-4KkHTYzEHihKL6co8obKxe
key:                  loop-0.3.0-4KkHTYzEHihKL6co8obKxe
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  9beaea91efbb1d716c2b68041943ad8f
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loop
hs-libraries:         HSloop-0.3.0-4KkHTYzEHihKL6co8obKxe
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loop
version:              0.3.0
visibility:           public
id:                   loop-0.3.0-KOXplhQaCiOD5uomfHlcpa
key:                  loop-0.3.0-KOXplhQaCiOD5uomfHlcpa
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/loop
synopsis:             Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.

    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.

category:             Control
abi:                  2e15e7be618bda5b67789bfa94daee21
exposed:              True
exposed-modules:      Control.Loop Control.Loop.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/loop-0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loop
hs-libraries:         HSloop-0.3.0-KOXplhQaCiOD5uomfHlcpa
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html:         /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
